Opportunities - Federal Business Opportunities: Opportunities

# Accessibility Information

Users of assistive technologies such as screen readers should use the following link to activate Accessibility Mode before continuing: Learn more and Activate accessibility mode.

- Skip to content
- tabs
- main menu
- Accessibility Mode

# Federal Business Opportunities

- IAE
- eGov
- USA.gov

- #### Buyers:

  Login | Register

- #### Vendors:

  Login | Register
- Accessibility

# Opportunities

### Return

- Opportunities List
- Advanced Search
- Archives

## Search Tip:

Use the Advanced Search Form for a wide array of search fields. To view opportunities by agency, go to the Agencies section. A quick search can be conducted using the fields below.

Keyword / Solicitation #: Tips Posted Date: Search by Agency, Set-aside, State, and Type Search by Classification, NAICS code, Recovery actions, and more
Agency: | Click and begin typing to initiate search
Place of Performance State: |
Type: |
Presolicitation | Combined Synopsis/Solicitation | Sources Sought
Modification/Amendment/Cancel | Sale of Surplus Property | Special Notice
Foreign Government Standard | Award Notice | Justification and Approval (J&A)
Intent to Bundle Requirements (DoD-Funded) | Fair Opportunity / Limited Sources Justification
Set-aside Code: |
Competitive 8(a) | Partial HBCU / MI | Total HBCU / MI
Emerging Small Business | Partial Small Business | Total Small Business
HUBZone | Service-Disabled Veteran-Owned Small Business | Veteran-Owned Small Business
Woman Owned Small Business | Economically Disadvantaged Woman Owned Small Business | Very Small Business

Sort By
Showing
per page 1 | 2 | 3 | 4 | 5 | 6 | 7 » [1274]
1 - 20 of 25476

Opportunity | Agency/Office/Location | Type / Set-aside | Posted On
--- | --- | --- | ---
65--Glidescope titanium single-use larynogoscope blades VA24416Q0183 65 -- Medical, dental & veterinary equipment & supplies | Department of Veterans Affairs Network Contracting Office 4 Department of Veterans Affairs Pittsburgh Healthcare System | Solicitation | Dec 04, 2015
Photocopier supplies and services on a firm fixed price (cost per copy) charge SBE20015R0021 J -- Maintenance, repair & rebuilding of equipment | Department of State European Posts U.S. Embassy Brussels, Belgium | Award | Dec 04, 2015
Garmisch Custodial Services W912PB-15-R-3007 S -- Utilities and housekeeping services | Department of the Army Army Contracting Command, ECC 409th CSB RCO Bavaria (W912PB)(PARC Europe) | Combined Synopsis/Solicitation (Modified) | Dec 04, 2015
VPQ Trailer Requirements 7503XSourcesSoughtWPCTrailer 23 -- Ground effects vehicles, motor vehicles, trailers & cycles | Department of the Air Force US Air Force Europe 700 CONS | Sources Sought (Modified) | Dec 04, 2015
DPW Dump Trucks W912PA-15-T-0082 23 -- Ground effects vehicles, motor vehicles, trailers & cycles | Department of the Army Army Contracting Command, ECC 409th CSB RCO Benelux (PARC Europe) | Award | Dec 04, 2015
53--SEAL,PLAIN 53 -- Hardware & abrasives | Defense Logistics Agency DLA Acquisition Locations DLA Troop Support - Construction & Equipment - BSM | Award | Dec 04, 2015
Y-- Design and Build Renovation Of University Clinic of Neurology - Skopje, Macedonia N3319116R1405 Y -- Construction of structures and facilities | Department of the Navy Naval Facilities Engineering Command NAVFAC Europe and Southwest Asia | Presolicitation | Dec 04, 2015
Vehicle Requirements in Support of Senior High Level USG VIP Visit V -- Transportation, travel, & relocation services | Department of State East Asian & Pacific Posts U.S. Embassy Manila, Philippines | Justification and Approval (J&A) | Dec 04, 2015
Vehicle Rental Services in Support of High Level VIP Visit V -- Transportation, travel, & relocation services | Department of State East Asian & Pacific Posts U.S. Embassy Manila, Philippines | Justification and Approval (J&A) | Dec 04, 2015
Hotel Accomodations for High level USG Visit V -- Transportation, travel, & relocation services | Department of State East Asian & Pacific Posts U.S. Embassy Manila, Philippines | Justification and Approval (J&A) | Dec 04, 2015
U--NEW ORDER Arresting Communication Course (VA LETC) VA119A16Q0033 U -- Education & training services | Department of Veterans Affairs VA Center for Acquisition Innovation (Frederick) VA CAI Frederick | Award | Dec 04, 2015
Leased Vehicle Support - Israel W912GB-15-T-0012 W -- Lease or Rental of equipment | Department of the Army U.S. Army Corps of Engineers USACE District, Europe | Award | Dec 04, 2015
RFQ AMEND 0001 HC1021-16-T-1005 D -- Information technology services, including telecommunications services | Defense Information Systems Agency Procurement Directorate DITCO-Europe | Combined Synopsis/Solicitation (Modified) | Dec 04, 2015
Army Europe Information Technology Training Program W564KV-16-R-0032 D -- Information technology services, including telecommunications services | Department of the Army Army Contracting Command, ECC 409th CSB TCC-Kaiserslautern (PARC Europe) | Sources Sought (Modified) | Dec 04, 2015
Cambodia Malaria Elimination Project SOL-442-16-000001 R -- Professional, administrative, and management support services | Agency for International Development Overseas Missions Cambodia USAID-PhnomPenh | Combined Synopsis/Solicitation | Dec 04, 2015
CP TANGO Balcony Renovation W91QVN16T0018 71 -- Furniture | Department of the Army Army Contracting Command, ECC 411TH CSB - RCC YONGSAN (PARC Korea) | Combined Synopsis/Solicitation (Modified) | Dec 04, 2015
Repair Eroding Retaining Wall & Storm Drainage W91QVN-16-R-0023 Z -- Maintenance, repair, and alteration of real property | Department of the Army Army Contracting Command, ECC 411TH CSB - RCC YONGSAN (PARC Korea) | Combined Synopsis/Solicitation | Dec 04, 2015
Warriors Club Buffet Line Furniture NAFIB3-16-Q-0005 72 -- Household & commercial furnishings & appliances | Department of the Army Non-Appropriated Funds US Army Family and MWR Command | Combined Synopsis/Solicitation | Dec 04, 2015
Program Management & Acquisition Support 02QFA1301 R -- Professional, administrative, and management support services | General Services Administration Federal Acquisition Service (FAS) Assisted Acquisition Services Division (2QFA) | Fair Opportunity / Limited Sources Justification | Dec 03, 2015
99--72 PORT EXPANSION M6261316T0010 99 -- Miscellaneous | Department of the Navy United States Marine Corps MCAS Iwakuni | Presolicitation / Total Small Business | Dec 03, 2015

Showing
per page 1 | 2 | 3 | 4 | 5 | 6 | 7 » [1274]
1 - 20 of 25476

- For Help: Federal Service Desk
- Accessibility